<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;

class RefreshPermission extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'refresh:permission {--force}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Refresh permission';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $force = $this->option('force');

        if (\App::environment('production') && ! $force) {
            $this->error('Could not reset in production mode');
            exit;
        }

        activity()->disableLogging();

        \Artisan::call('cache:clear');

        \DB::statement('SET FOREIGN_KEY_CHECKS=0;');
        \DB::table('role_has_permissions')->truncate();
        \DB::table('permissions')->truncate();
        \DB::table('roles')->truncate();
        \DB::statement('SET FOREIGN_KEY_CHECKS=1;');

        \Artisan::call('db:seed', ['--class' => 'RoleSeeder', '--force' => $force ? true : false]);
        \Artisan::call('db:seed', ['--class' => 'PermissionSeeder', '--force' => $force ? true : false]);
        \Artisan::call('db:seed', ['--class' => 'AssignPermissionSeeder', '--force' => $force ? true : false]);

        activity()->enableLogging();
    }
}
