<?php

namespace App\Http\Controllers\Accounting;

use App\Http\Controllers\Controller;
use App\Http\Requests\Accounting\FollowUpRequest;
use App\Http\Resources\Accounting\FollowUp;
use App\Models\Accounting\Voucher;
use App\Repositories\Accounting\FollowUpRepository;
use Illuminate\Http\Request;

class FollowUpController extends Controller
{
    private $request;
    private $repo;

    /**
     * Instantiate a new controller instance
     * @return void
     */
    public function __construct(
        Request $request,
        FollowUpRepository $repo
    ) {
        $this->request  = $request;
        $this->repo     = $repo;
    }

    /**
     * Store follow up
     * @post ("/api/accounting/voucher/{voucher}/{uuid}/follow-ups")
     * @param ({
     *      @Parameter("voucher", type="array", required="true", description="Voucher"),
     * })
     * @return array
     */
    public function store(FollowUpRequest $request, $type, $uuid)
    {
        $this->authorize('followUp', Voucher::class);

        $follow_up = new FollowUp($this->repo->create($uuid));

        return $this->success(['message' => __('global.added', ['attribute' => __('sale.enquiry.followup.followup')]), 'follow_up' => $follow_up]);
    }
}
