<?php

namespace App\Http\Controllers\Accounting;

use App\Http\Controllers\Controller;
use App\Models\Accounting\Ledger;
use App\Repositories\Accounting\LedgerReportRepository;
use Illuminate\Http\Request;

class LedgerReportController extends Controller
{
    private $request;
    private $repo;

    /**
     * Instantiate a new controller instance
     * @return void
     */
    public function __construct(
        Request $request,
        LedgerReportRepository $repo
    ) {
        $this->request  = $request;
        $this->repo     = $repo;

        $this->middleware(['permission:access-ledger-report']);
    }

    /**
     * Get ledger report
     * @get ("/api/accounting/ledgers/{ledger}/report")
     * @param ({
     *      @Parameter("ledger", type="uuid", required="true", description="Ledger unique id"),
     * })
     */
    public function getReport(Ledger $ledger)
    {
        $this->authorize('report', Ledger::class);

        return $this->ok($this->repo->getReport($ledger));
    }
}
