<?php

namespace App\Http\Controllers\Accounting;

use App\Http\Controllers\Controller;
use App\Http\Requests\Accounting\TransactionRequest;
use App\Models\Accounting\Transaction;
use App\Repositories\Accounting\TransactionRepository;
use Illuminate\Http\Request;
use App\Http\Resources\Accounting\Transaction as TransactionResource;

class TransactionController extends Controller
{
    private $request;
    private $repo;

    /**
     * Instantiate a new controller instance
     * @return void
     */
    public function __construct(
        Request $request,
        TransactionRepository $repo
    ) {
        $this->request  = $request;
        $this->repo     = $repo;
    }

    /**
     * Get pre requisites
     * @get ("/api/accounting/transactions/pre-requisite")
     * @return array
     */
    public function preRequisite()
    {
        return $this->ok($this->repo->getPreRequisite());
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $this->authorize('viewAny', Transaction::class);

        return $this->repo->paginate();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TransactionRequest $request)
    {
        $this->authorize('create', Transaction::class);

        $transaction = new TransactionResource($this->repo->create());

        return $this->success(['message' => __('global.added', ['attribute' => __('transaction.transaction')]), 'transaction' => $transaction]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Accounting\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function show(Transaction $transaction)
    {
        $this->authorize('view', $transaction);

        return new TransactionResource($transaction);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Accounting\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function update(TransactionRequest $request, Transaction $transaction)
    {
        $this->authorize('update', $transaction);

        $this->repo->update($transaction);

        return $this->success(['message' => __('global.updated', ['attribute' => __('transaction.transaction')])]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Accounting\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function destroy(Transaction $transaction)
    {
        $this->authorize('delete', $transaction);

        $this->repo->delete($transaction);

        return $this->success(['message' => __('global.deleted', ['attribute' => __('transaction.transaction')])]);
    }
}
