<?php

namespace App\Http\Controllers\Inventory;

use App\Http\Controllers\Controller;
use App\Models\Inventory\Item;
use App\Repositories\Inventory\ItemReportRepository;
use Illuminate\Http\Request;

class ItemReportController extends Controller
{
    private $request;
    private $repo;

    /**
     * Instantiate a new controller instance
     * @return void
     */
    public function __construct(
        Request $request,
        ItemReportRepository $repo
    ) {
        $this->request  = $request;
        $this->repo     = $repo;

        $this->middleware(['permission:access-item-report']);
    }

    /**
     * Get item report
     * @get ("/api/inventory/items/{item}/report")
     * @param ({
     *      @Parameter("item", type="uuid", required="true", description="Item unique id"),
     * })
     */
    public function getReport(Item $item)
    {
        $this->authorize('report', Item::class);

        return $this->ok($this->repo->getReport($item));
    }
}
