<?php

namespace App\Http\Controllers\Setting;

use App\Models\Setting\Margin;
use App\Http\Controllers\Controller;
use App\Http\Requests\Setting\MarginRequest;
use App\Repositories\Setting\MarginRepository;
use App\Http\Resources\Setting\Margin as MarginResource;
use Illuminate\Http\Request;

class MarginController extends Controller
{
    protected $repo;

    /**
     * Instantiate a new instance
     * @return void
     */
    public function __construct(
        MarginRepository $repo
    ) {
        $this->repo = $repo;

        $this->middleware(['permission:manage-margin']);
    }

    /**
     * Get pre requisites
     * @get ("/api/setting/margins/pre-requisite")
     * @return array
     */
    public function preRequisite()
    {
        return $this->ok($this->repo->getPreRequisite());
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return $this->repo->paginate();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(MarginRequest $request)
    {
        $margin = $this->repo->create();

        $margin = new MarginResource($margin);

        return $this->success(['message' => __('global.added', ['attribute' => __('setting.margin.margin')]), 'margin' => $margin]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Setting\Margin  $margin
     * @return \Illuminate\Http\Response
     */
    public function show(Margin $margin)
    {
        return new MarginResource($margin);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Setting\Margin  $margin
     * @return \Illuminate\Http\Response
     */
    public function update(MarginRequest $request, Margin $margin)
    {
        $margin = $this->repo->update($margin);

        return $this->success(['message' => __('global.updated', ['attribute' => __('setting.margin.margin')])]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Setting\Margin  $margin
     * @return \Illuminate\Http\Response
     */
    public function destroy(Margin $margin)
    {
        $this->repo->delete($margin);

        return $this->success(['message' => __('global.deleted', ['attribute' => __('setting.margin.margin')])]);
    }
}