<?php

namespace App\Http\Controllers\Setting;

use App\Models\Setting\Tax;
use App\Http\Controllers\Controller;
use App\Http\Requests\Setting\TaxRequest;
use App\Repositories\Setting\TaxRepository;
use App\Http\Resources\Setting\Tax as TaxResource;
use Illuminate\Http\Request;

class TaxController extends Controller
{
    protected $repo;

    /**
     * Instantiate a new instance
     * @return void
     */
    public function __construct(
        TaxRepository $repo
    ) {
        $this->repo = $repo;

        $this->middleware(['permission:manage-tax']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return $this->repo->paginate();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TaxRequest $request)
    {
        $tax = $this->repo->create();

        $tax = new TaxResource($tax);

        return $this->success(['message' => __('global.added', ['attribute' => __('setting.tax.tax')]), 'tax' => $tax]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Setting\Tax  $tax
     * @return \Illuminate\Http\Response
     */
    public function show(Tax $tax)
    {
        return new TaxResource($tax);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Setting\Tax  $tax
     * @return \Illuminate\Http\Response
     */
    public function update(TaxRequest $request, Tax $tax)
    {
        $tax = $this->repo->update($tax);

        return $this->success(['message' => __('global.updated', ['attribute' => __('setting.tax.tax')])]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Setting\Tax  $tax
     * @return \Illuminate\Http\Response
     */
    public function destroy(Tax $tax)
    {
        $this->repo->delete($tax);

        return $this->success(['message' => __('global.deleted', ['attribute' => __('setting.tax.tax')])]);
    }
}