<?php

namespace App\Http\Controllers\Setting;

use App\Models\Setting\Unit;
use App\Http\Controllers\Controller;
use App\Http\Requests\Setting\UnitRequest;
use App\Repositories\Setting\UnitRepository;
use App\Http\Resources\Setting\Unit as UnitResource;
use Illuminate\Http\Request;

class UnitController extends Controller
{
    protected $repo;

    /**
     * Instantiate a new instance
     * @return void
     */
    public function __construct(
        UnitRepository $repo
    ) {
        $this->repo = $repo;

        $this->middleware(['permission:manage-unit']);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return $this->repo->paginate();
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(UnitRequest $request)
    {
        $unit = $this->repo->create();

        $unit = new UnitResource($unit);

        return $this->success(['message' => __('global.added', ['attribute' => __('setting.unit.unit')]), 'unit' => $unit]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Setting\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function show(Unit $unit)
    {
        return new UnitResource($unit);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Setting\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function update(UnitRequest $request, Unit $unit)
    {
        $unit = $this->repo->update($unit);

        return $this->success(['message' => __('global.updated', ['attribute' => __('setting.unit.unit')])]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Setting\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function destroy(Unit $unit)
    {
        $this->repo->delete($unit);

        return $this->success(['message' => __('global.deleted', ['attribute' => __('setting.unit.unit')])]);
    }
}
