<?php

namespace App\Http\Requests\Accounting;

use App\Traits\Validation;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class TransactionRequest extends FormRequest
{
    use Validation;

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $uuid = $this->route('ledger');

        return [
            'type'               => 'required',
            'date'               => 'required|date',
            'ledger'             => 'required|array',
            'rows'               => 'required|array|min:1',
            'rows.*.ledger.uuid' => 'required|distinct',
            'rows.*.amount'      => 'required|numeric|min:0',
        ];
    }

    /**
     * Translate fields with user friendly name.
     *
     * @return array
     */
    public function attributes()
    {
        return [
            'type'               => trans('transaction.props.type'),
            'date'               => trans('transaction.props.date'),
            'ledger'             => trans('accounting.ledger.ledger'),
            'rows.*.ledger.uuid' => trans('accounting.ledger.ledger')
        ];
    }

    public function withValidator($validator)
    {
        $validator->after(function ($validator) {
            $this->simplify($validator, 'rows.*.ledger.uuid', 'rows.*.ledger');
        });
    }
}
