<?php

namespace App\Http\Requests\Inventory;

use App\Traits\Validation;
use Illuminate\Foundation\Http\FormRequest;

class StockMatchRequest extends FormRequest
{
    use Validation;

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $rules = [
            'date'                              => 'required|date',
            'item_category'                     => 'required|array|min:1',
            'items'                             => 'required|array|min:1',
            'items.*.item.uuid'                 => 'required|distinct',
            'items.*.actual_quantity_non_taxed' => 'integer',
            'items.*.actual_quantity_taxed'     => 'integer'
        ];

        return $rules;
    }

    /**
     * Translate fields with user friendly name.
     *
     * @return array
     */
    public function attributes()
    {
        return [
            'items.*.item.uuid' => trans('inventory.item.item')
        ];
    }

    public function withValidator($validator)
    {
        $validator->after(function ($validator) {
            $this->change($validator, 'items', 'message');
            $this->simplify($validator, 'items.*.item.uuid', 'items.*.item');
        });
    }

    /**
     * Translate rules with user friendly name.
     *
     * @return array
     */
    public function messages()
    {
        return [];
    }
}
