<?php

namespace App\Http\Resources\Accounting;

use App\Helpers\CalHelper;
use App\Http\Resources\Contact as ContactResource;
use App\Http\Resources\ContactCollection;
use App\Http\Resources\TagCollection;
use App\Traits\LedgerConstraints;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;

class Ledger extends JsonResource
{
    use LedgerConstraints;

    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $is_business = (bool) $this->getMeta('is_business');

        $contact = $this->contacts()->firstWhere('is_primary', 1);
        $contacts = $this->contacts->where('is_primary', 0);

        $net_balance_taxed = $this->opening_balance_taxed + $this->current_balance_taxed;
        $net_balance_non_taxed = $this->opening_balance_non_taxed + $this->current_balance_non_taxed;

        return [
           'uuid'                      => $this->uuid,
           'name'                      => $this->name,
           'billing_name'              => $this->getMeta('billing_name') ?? $this->name,
           'alias'                     => $this->alias,
           'opening_balance_taxed'     => $this->opening_balance_taxed,
           'opening_balance_non_taxed' => $this->opening_balance_non_taxed,
           'current_balance_taxed'     => $this->current_balance_taxed,
           'current_balance_non_taxed' => $this->current_balance_non_taxed,
           'net_balance_taxed'         => abs($net_balance_taxed),
           'taxed_class'               => $this->getClass($this->type->code, $net_balance_taxed),
           'net_balance_non_taxed'     => abs($net_balance_non_taxed),
           'non_taxed_class'           => $this->getClass($this->type->code, $net_balance_non_taxed),
           'is_business'               => $is_business,
           'business_code1'            => $this->when($is_business, $this->getMeta('business_code1')),
           'business_code2'            => $this->when($is_business, $this->getMeta('business_code2')),
           'business_code2'            => $this->when($is_business, $this->getMeta('business_code2')),
           'ledger_type'               => new LedgerType($this->whenLoaded('type')),
           'contact'                   => $this->when($this->type->has_contact, new ContactResource($contact)),
           'contacts'                  => $this->when($this->type->has_contact, new ContactCollection($contacts)),
           'accounts'                  => $this->when($this->type->has_account, new AccountCollection($this->whenLoaded('accounts'))),
           'tags'                      => new TagCollection($this->tags),
           'description'               => $this->description,
           'meta'                      => $this->meta,
           'created_at'                => CalHelper::toDateTime($this->created_at),
           'updated_at'                => CalHelper::toDateTime($this->updated_at)
        ];
    }
}
