<?php

namespace App\Http\Resources\Accounting;

use App\Helpers\CalHelper;
use App\Http\Resources\Contact as ContactResource;
use App\Http\Resources\ContactCollection;
use App\Traits\LedgerConstraints;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;

class LedgerSummary extends JsonResource
{
    use LedgerConstraints;

    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $is_business = (bool) $this->getMeta('is_business');

        $contact = $this->contacts()->firstWhere('is_primary', 1);

        $net_balance_taxed = $this->opening_balance_taxed + $this->current_balance_taxed;
        $net_balance_non_taxed = $this->opening_balance_non_taxed + $this->current_balance_non_taxed;

        return [
           'uuid'                      => $this->uuid,
           'name'                      => $this->name,
           'billing_name'              => $this->getMeta('billing_name') ?? $this->name,
           'alias'                     => $this->alias,
           'taxed_class'               => $this->getClass($this->type->code, $net_balance_taxed),
           'non_taxed_class'           => $this->getClass($this->type->code, $net_balance_non_taxed),
           'net_balance_taxed'         => $net_balance_taxed,
           'net_balance_non_taxed'     => $net_balance_non_taxed,
           'is_business'               => $is_business,
           'ledger_type'               => new LedgerType($this->whenLoaded('type')),
           'contact'                   => $this->when($this->type->has_contact, new ContactResource($contact)),
           'created_at'                => CalHelper::toDateTime($this->created_at),
           'updated_at'                => CalHelper::toDateTime($this->updated_at)
        ];
    }
}
