<?php

namespace App\Http\Resources\Accounting;

use Illuminate\Support\Str;
use App\Helpers\CalHelper;
use App\Helpers\SysHelper;
use App\Http\Resources\ContactSummary;
use App\Http\Resources\Option;
use App\Http\Resources\TagCollection;
use App\Http\Resources\UserSummary;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;

class Voucher extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'uuid'                   => $this->uuid,
            'code_number'            => $this->code_number,
            'date'                   => CalHelper::toDate($this->date),
            'due_date'               => CalHelper::toDate($this->due_date),
            'due_in_days'            => $this->due_date ? $this->due_date->diffInDays($this->date) : null,
            'delivery_date'          => CalHelper::toDate($this->delivery_date),
            'expected_delivery_date' => CalHelper::toDate($this->expected_delivery_date),
            'is_non_taxed'           => (bool) $this->is_non_taxed,
            'items'                  => new VoucherDetailCollection($this->whenLoaded('details')),
            'follow_ups'             => new FollowUpCollection($this->whenLoaded('followUps')),
            'ledger'                 => new Ledger($this->whenLoaded('ledger')),
            'contact'                => new ContactSummary($this->whenLoaded('contact')),
            'enquiry_type'           => $this->when($this->type == 'sale-enquiry', new Option($this->whenLoaded('enquiryType'))),
            'enquiry_source'         => $this->when($this->type == 'sale-enquiry', new Option($this->whenLoaded('enquirySource'))),
            'subject'                => $this->subject,
            'description'            => $this->description,
            'memo'                   => $this->memo,
            'note'                   => $this->note,
            'reference_number'       => $this->reference_number,
            'referral'               => new ContactSummary($this->whenLoaded('referral')),
            'round_off'              => (float) $this->round_off,
            'shipping'               => (float) $this->shipping,
            'transport'              => new Option($this->whenLoaded('transport')),
            'tracking_number'        => $this->tracking_number,
            'taxes'                  => $this->getTaxes(),
            'discounts'              => $this->discount,
            'is_published'           => (bool) $this->status,
            'status'                 => $this->status_detail,
            'payment_status'         => $this->payment_status,
            'tags'                   => new TagCollection($this->tags),
            'total'                  => array(
                // ADDED BECUASE EDITING FORM ISN'T CORRECTLY POPULATING
                // TO BE REMOVED LATER WHEN SOLUTION FOUND
                // START
                'quantity' => 0,
                'rate' => 0,
                'rate_with_tax' => 0,
                'rate_with_discount' => 0,
                'rate_with_tax_discount' => 0,
                'amount' => 0,
                'amount_with_tax' => 0,
                'amount_with_discount' => 0,
                'amount_with_tax_discount' => 0,
                'amount_with_all_discounts' => 0,
                'amount_total' => 0,
                'discounts_total_amount' => 0,
                'taxes_total_amount' => 0,
                'voucher_level_taxes_total_amount' => 0,
                // END
                'total_amount' => SysHelper::formatCurrency($this->total)
            ),
            'billing_info' => $this->getInfo('billing_info'),
            'user'       => new UserSummary($this->whenLoaded('user')),
            'created_at' => CalHelper::toDateTime($this->created_at),
            'updated_at' => CalHelper::toDateTime($this->updated_at)
        ];
    }

    private function getTaxes()
    {
        $taxes = array();
        $item_taxes = array();
        foreach ($this->details as $detail) {
            $detail_tax = is_array($detail->tax) ? $detail->tax : [];
            foreach ($detail_tax as $tax) {
                $item_taxes[] = array(
                    'uuid' => Arr::get($tax, 'uuid'),
                    'tax' => array(
                        'uuid' => Arr::get($tax, 'uuid'),
                        'value' => Arr::get($tax, 'value'),
                        'name' => Arr::get($tax, 'name'),
                        'voucher_level_tax' => (bool) Arr::get($tax, 'voucher_level_tax'),
                        'calculate_on_total' => (bool) Arr::get($tax, 'calculate_on_total'),
                    ),
                    'amount' => (float) Arr::get($tax, 'amount')
                );
            }
        }

        $group_taxes = collect($item_taxes)->groupBy('uuid')->map(function ($row) {
            return array(
                'uuid' => Str::uuid(),
                'amount' => $row->sum('amount'),
                'tax' => $row[0]['tax']
            );
        });

        foreach ($group_taxes as $group_tax) {
            $taxes[] = $group_tax;
        }

        $voucher_tax = is_array($this->tax) ? $this->tax : [];
        foreach ($voucher_tax as $tax) {
            $taxes[] = array(
                'uuid' => Str::uuid(),
                'tax' => array(
                    'uuid' => Arr::get($tax, 'uuid'),
                    'value' => Arr::get($tax, 'value'),
                    'name' => Arr::get($tax, 'name'),
                    'voucher_level_tax' => (bool) Arr::get($tax, 'voucher_level_tax'),
                    'calculate_on_total' => (bool) Arr::get($tax, 'calculate_on_total'),
                ),
                'amount' => Arr::get($tax, 'amount')
            );
        }

        return $taxes;
    }
}
