<?php

namespace App\Http\Resources\Accounting;

use App\Helpers\CalHelper;
use App\Helpers\SysHelper;
use App\Http\Resources\Inventory\Item;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;
use Illuminate\Support\Str;

class VoucherDetail extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $tax      = $this->tax[0] ?? null;
        $discount = $this->discount[0] ?? [];

        return [
            'uuid'                     => $this->uuid,
            'is_non_taxed'             => (bool) $this->is_non_taxed,
            'quantity'                 => (float) $this->quantity,
            'rate'                     => SysHelper::formatCurrency($this->rate),
            'amount_with_tax_discount' => SysHelper::formatCurrency($this->amount),
            'discount'                 => Arr::get($discount, 'value'),
            'discount_amount'          => Arr::get($discount, 'amount'),
            'tax'                      => $tax,
            'description'              => $this->description,
            'is_fulfilled'             => (bool) $this->getMeta('is_fulfilled'),
            'custom'                   => $this->item_id ? false : true,
            'item'                     => $this->getItem(),

            'rate_with_discount'       => null,
            'rate_with_tax'            => null,
            'rate_with_tax_discount'   => null,
            'amount_with_discount'     => null,
            'amount_with_all_discounts' => null,
            'amount_with_tax'          => null,
            'amount_total'             => null,

            'created_at'               => CalHelper::toDateTime($this->created_at),
            'updated_at'               => CalHelper::toDateTime($this->updated_at)
        ];
    }

    private function getItem()
    {
        if (is_null($this->item_name)) {
            return new Item($this->whenLoaded('item'));
        }

        return array(
            'alias' => '',
            'description' => '',
            'name' => $this->item_name,
            'tax' => array(
                'calculate_on_total' => false,
                'code' => 'custom',
                'name' => trans('inventory.item.props.custom'),
                'uuid' => (string) Str::uuid(),
                'value' => '',
                'voucher_level_tax' => false
            ),
            'unit' => array(
                'code' => $this->unit_name,
                'decimal_point' => 0,
                'name' => $this->unit_name,
                'uuid' => (string) Str::uuid(),
            ),
            'uuid' => $this->uuid,
        );
    }
}
