<?php

namespace App\Http\Resources\Accounting;

use App\Helpers\CalHelper;
use App\Helpers\SysHelper;
use App\Http\Resources\ContactSummary;
use App\Http\Resources\Option;
use App\Http\Resources\TagCollection;
use App\Http\Resources\UserSummary;
use Illuminate\Http\Resources\Json\JsonResource;

class VoucherSummary extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
            'uuid'           => $this->uuid,
            'code_number'    => $this->code_number,
            'type'           => $this->type,
            'date'           => CalHelper::toDate($this->date),
            'is_non_taxed'   => (bool) $this->is_non_taxed,
            'is_published'   => (bool) $this->status,
            'payment_status' => $this->payment_status,
            'total'          => SysHelper::formatCurrency($this->total),
            'ledger'         => new LedgerSummary($this->whenLoaded('ledger')),
            'contact'        => new ContactSummary($this->whenLoaded('contact')),
            'enquiry_type'   => $this->when($this->type == 'sale-enquiry', new Option($this->whenLoaded('enquiryType'))),
            'enquiry_source' => $this->when($this->type == 'sale-enquiry', new Option($this->whenLoaded('enquirySource'))),
            'subject'        => $this->subject,
            'status'         => $this->status_detail,
            'tags'           => new TagCollection($this->tags),
            'user'           => new UserSummary($this->whenLoaded('user')),
            'created_at'     => CalHelper::toDateTime($this->created_at),
            'updated_at'     => CalHelper::toDateTime($this->updated_at)
        ];
    }
}
