<?php

namespace App\Http\Resources;

use App\Helpers\ArrHelper;
use App\Helpers\CalHelper;
use App\Http\Resources\Accounting\LedgerCollection;
use App\Http\Resources\Inventory\BrandCollection;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;

class Contact extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        return [
           'uuid'             => $this->uuid,
           'name'             => $this->name,
           'alias'            => $this->alias,
           'phone'            => $this->phone,
           'ledgers'          => new LedgerCollection($this->whenLoaded('ledgers')),
           'brands'           => new BrandCollection($this->whenLoaded('brands')),
           'mobile'           => $this->mobile,
           'alt_mobile'       => $this->alt_mobile,
           'email'            => $this->email,
           'alt_email'        => $this->alt_email,
           'birth_date'       => CalHelper::toDate($this->birth_date),
           'age'              => CalHelper::getAge($this->birth_date),
           'anniversary_date' => CalHelper::toDate($this->anniversary_date),
           'gender'           => $this->gender ? ArrHelper::searchByKey(ArrHelper::getTransList('genders'), 'uuid', $this->gender) : null,
           'avatar'           => $this->avatar,
           'designation'      => $this->designation,
           'is_primary'       => (bool) $this->is_primary,
           'is_business'      => (bool) $this->getMeta('is_business'),
           'address_line1'    => Arr::get($this->address, 'address_line1'),
           'address_line2'    => Arr::get($this->address, 'address_line2'),
           'city'             => Arr::get($this->address, 'city'),
           'state'            => Arr::get($this->address, 'state'),
           'zipcode'          => Arr::get($this->address, 'zipcode'),
           'country'          => Arr::get($this->address, 'country'),
           'has_same_address' => (bool) $this->has_same_address,
           'tags'             => new TagCollection($this->tags),
           'created_at'       => CalHelper::toDateTime($this->created_at),
           'updated_at'       => CalHelper::toDateTime($this->updated_at)
        ];
    }
}
