<?php

namespace App\Http\Resources\Inventory;

use App\Helpers\CalHelper;
use App\Http\Resources\Setting\Margin;
use App\Http\Resources\Setting\Tax;
use App\Http\Resources\Setting\Unit;
use App\Http\Resources\TagCollection;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Str;
use Illuminate\Support\Arr;

class ItemCategory extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function toArray($request)
    {
        $variants = $this->variants ? : [];

        $variants = collect($variants)->transform(function($variant) {
            $options = Arr::get($variant, 'options', []);
            $options = collect($options)->transform(function($option) {
                $option_name = Arr::get($option, 'name');
                return array('uuid' => Str::slug($option_name), 'name' => $option_name);
            })->all();
            $variant_name = Arr::get($variant, 'name');
            $variant_type = Arr::get($variant, 'type');

            if (! $variant_type && count($options)) {
                $variant_type = 'single_select';
            } else if (! $variant_type && ! count($options)) {
                $variant_type = 'text';
            }

            return array('uuid' => Str::slug($variant_name), 'name' => $variant_name, 'type' => array('uuid' => $variant_type, 'name' => trans('list.inventory.variant_types.' . $variant_type)), 'options' => $options);
        });

        return [
            'uuid'                     => $this->uuid,
            'name'                     => $this->name,
            'alias'                    => $this->alias,
            'type'                     => array('uuid' => $this->type, 'name' => trans('list.inventory.types.' . $this->type)),
            'price_calculation_method' => array('uuid' => $this->price_calculation_method, 'name' => trans('list.inventory.price_calculation_methods.' . $this->price_calculation_method)),
            // 'stock_match_date'         => CalHelper::toDate(optional($this->stockMatches->first())->date),
            'stock_match_date' => CalHelper::toDate($this->last_stock_match_date),
            'unit'             => new Unit($this->whenLoaded('unit')),
            'tax'              => new Tax($this->whenLoaded('tax')),
            'margin'           => new Margin($this->whenLoaded('margin')),
            'parent'           => new self($this->whenLoaded('parent')),
            'description'      => $this->description,
            'variants'         => $variants,
            'prefix'           => Arr::get($this->meta, 'prefix'),
            'tags'             => new TagCollection($this->tags),
            'created_at'       => CalHelper::toDateTime($this->created_at),
            'updated_at'       => CalHelper::toDateTime($this->updated_at)
        ];
    }
}
