<?php

namespace App\Models\Accounting;

use App\Models\Accounting\Voucher;
use App\Models\User;
use App\Traits\HasMeta;
use App\Traits\HasUuid;
use App\Traits\ModelOption;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Arr;
use Spatie\Activitylog\Traits\LogsActivity;

class FollowUp extends Model
{
    use HasUuid, HasMeta, ModelOption, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta'      => 'array',
        'date'      => 'date',
        'next_date' => 'date',
    ];
    protected $table = 'follow_ups';
    protected static $logName = 'follow_up';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected $with = [];

    // Meta
    public function getMeta(string $option)
    {
        return Arr::get($this->meta, $option);
    }

    public function voucher() : BelongsTo
    {
        return $this->belongsTo(Voucher::class);
    }

    public function user() : BelongsTo
    {
        return $this->belongsTo(User::class);
    }
}
