<?php

namespace App\Models\Accounting;

use App\Traits\HasMeta;
use App\Traits\HasParent;
use App\Traits\HasUuid;
use App\Traits\ModelOption;
use Illuminate\Support\Arr;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Spatie\Activitylog\Traits\LogsActivity;
use Spatie\Permission\Traits\HasRoles;

class LedgerType extends Model
{
    use HasUuid, HasMeta, ModelOption, HasParent, HasRoles, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta' => 'array',
    ];
    protected $table = 'ledger_types';
    protected static $logName = 'ledger_type';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected static $sortOptions = ['created_at', 'name', 'updated_at'];
    protected static $defaultSortBy = 'created_at';
    protected $with = ['parent', 'nestedParents'];

    // Meta
    public function getMeta(string $option)
    {
        return Arr::get($this->meta, $option);
    }

    public function getHasAccountAttribute()
    {
        return (bool) is_null($this->parent_id) ? $this->getMeta('has_account') : optional($this->topAncestor())->getMeta('has_account');
    }

    public function getHasContactAttribute()
    {
        return (bool) is_null($this->parent_id) ? $this->getMeta('has_contact') : optional($this->topAncestor())->getMeta('has_contact');
    }

    public function getLedgerTypeCodeAttribute()
    {
        return $this->code ?? optional($this->topAncestor())->code;
    }

    public function ledgers() : HasMany
    {
        return $this->hasMany(Ledger::class);
    }

    // Booted
    public static function booted()
    {
    }

    protected static function ensureUpdatable() : void
    {

    }

    // Filters

    public function scopeSearch(Builder $query, $search = null)
    {
        $fuzzy = implode("%", str_split($search));
        $fuzzy = "%$fuzzy%";

        $query->when($search, function ($q) use ($fuzzy) {
            return $q->where(function($q1) use ($fuzzy) {
                $q1->where('name', 'like', $fuzzy)
                ->orWhere('alias', 'like', $fuzzy)
                ->orWhere('description', 'like', $fuzzy);
            });
        });
    }

    public function scopeFilterById(Builder $query, $id) : void
    {
        $query->when($id, function ($q, $id) {
            return $q->where('id', '=', $id);
        });
    }

    public function scopeFilterByUuid(Builder $query, $uuid) : void
    {
        $query->when($uuid, function ($q, $uuid) {
            return $q->where('uuid', '=', $uuid);
        });
    }

    public function scopeFilterByName(Builder $query, $name = null) : void
    {
        $query->when($name, function ($q, $name) {
            return $q->where('name', 'like', '%'.$name.'%');
        });
    }

    public function scopeFilterByAlias(Builder $query, $alias = null) : void
    {
        $query->when($alias, function ($q, $alias) {
            return $q->where('alias', 'like', '%'.$alias.'%');
        });
    }

    public function scopeFilterByNameOrAlias(Builder $query, $keyword = null) : void
    {
        $query->when($keyword, function ($q, $keyword) {
            return $q->where(function($q1) use ($keyword) {
                $q1->where('name', 'like', '%'.$keyword.'%')->orWhere('alias', 'like', '%'.$keyword.'%');
            });
        });
    }
}
