<?php

namespace App\Models\Accounting;

use App\Models\Setting\Tax;
use App\Traits\HasMeta;
use App\Traits\HasUuid;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Arr;
use Spatie\Activitylog\Traits\LogsActivity;

class VoucherTax extends Model
{
    use HasUuid, HasMeta, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta'         => 'array',
    ];
    protected $table = 'voucher_taxes';
    protected static $logName = 'voucher';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected $with = [];

    // Meta
    public function getMeta(string $option)
    {
        return Arr::get($this->meta, $option);
    }

    public function voucher() : BelongsTo
    {
        return $this->belongsTo(Voucher::class);
    }

    public function tax() : BelongsTo
    {
        return $this->belongsTo(Tax::class);
    }

    // Booted
    public static function booted()
    {
    }

    protected static function ensureUpdatable() : void
    {

    }

    // Filters
    public function scopeFilterById(Builder $query, $id) : void
    {
        $query->when($id, function ($q, $id) {
            return $q->where('id', '=', $id);
        });
    }

    public function scopeFilterByUuid(Builder $query, $uuid) : void
    {
        $query->when($uuid, function ($q, $uuid) {
            return $q->where('uuid', '=', $uuid);
        });
    }
}
