<?php

namespace App\Models\Inventory;

use App\Models\Contact;
use App\Models\Tag;
use App\Traits\HasContact;
use App\Traits\HasMeta;
use App\Traits\HasUuid;
use App\Traits\ModelOption;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Builder;
use Spatie\Activitylog\Traits\LogsActivity;

class Brand extends Model
{
    use HasMeta, HasUuid, HasContact, ModelOption, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta' => 'array'
    ];
    protected $table = 'brands';
    protected static $logName = 'brand';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected static $sortOptions = ['created_at', 'name', 'updated_at'];
    protected static $defaultSortBy = 'name';
    protected $with = ['tags'];

    // Relations

    public function contacts()
    {
        return $this->morphToMany(Contact::class, 'contactable');
    }

    public function items()
    {
        return $this->hasMany(Item::class);
    }

    public function tags()
    {
        return $this->morphToMany(Tag::class, 'taggable');
    }

    // Booted
    public static function booted()
    {
    }

    protected static function ensureUpdatable() : void
    {
    }

    // Filters

    public function scopeSearch(Builder $query, $search = null)
    {
        $fuzzy = implode("%", str_split($search));
        $fuzzy = "%$fuzzy%";

        $query->when($search, function ($q) use ($fuzzy) {
            return $q->where(function($q1) use ($fuzzy) {
                $q1->where('name', 'like', $fuzzy)
                ->orWhere('alias', 'like', $fuzzy)
                ->orWhere('description', 'like', $fuzzy);
            });
        });
    }

    public function scopeFilterByName(Builder $query, $name = null) : void
    {
        $query->when($name, function ($q, $name) {
            return $q->where('name', 'like', '%'.$name.'%');
        });
    }
}
