<?php

namespace App\Models\Inventory;

use App\Models\Inventory\StockMatchDetail;
use App\Models\User;
use App\Traits\HasMeta;
use App\Traits\HasUuid;
use App\Traits\ModelOption;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Arr;
use Spatie\Activitylog\Traits\LogsActivity;

class StockMatch extends Model
{
    use HasUuid, HasMeta, ModelOption, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta' => 'array',
        'date' => 'date',
    ];
    protected $table = 'stock_matches';
    protected static $logName = 'stock_match';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected $with = [];
    protected static $sortOptions = ['created_at', 'date', 'updated_at'];
    protected static $defaultSortBy = 'date';

    // Meta
    public function getMeta(string $option)
    {
        return Arr::get($this->meta, $option);
    }

    public function details() : HasMany
    {
        return $this->hasMany(StockMatchDetail::class);
    }

    public function itemCategory() : BelongsTo
    {
        return $this->belongsTo(ItemCategory::class);
    }

    public function user() : BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    // Booted
    public static function booted()
    {
    }

    protected static function ensureUpdatable() : void
    {

    }

    // Filters

    public function scopeInfo(Builder $query) : void
    {
        $query->with('itemCategory', 'user');
    }

    public function scopeFilterById(Builder $query, $id) : void
    {
        $query->when($id, function ($q, $id) {
            return $q->where('id', '=', $id);
        });
    }

    public function scopeFilterByUuid(Builder $query, $uuid) : void
    {
        $query->when($uuid, function ($q, $uuid) {
            return $q->where('uuid', '=', $uuid);
        });
    }

    public function scopeDateBetween(Builder $query, $dates = array()) : void
    {
        $start_date = Arr::get($dates, 'start_date');
        $end_date = Arr::get($dates, 'end_date') ? : $start_date;

        if ($start_date && $end_date && $start_date <= $end_date) {
            $query->where('date', '>=', $start_date)->where('date', '<=', $end_date);
        }
    }
}
