<?php

namespace App\Models\Inventory;

use App\Models\Inventory\Item;
use App\Traits\HasMeta;
use App\Traits\HasUuid;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Arr;
use Spatie\Activitylog\Traits\LogsActivity;

class StockMatchDetail extends Model
{
    use HasUuid, HasMeta, LogsActivity;

    protected $guarded = [];
    protected $casts = [
        'meta'   => 'array',
        'billed' => 'array',
        'actual' => 'array',
    ];
    protected $table = 'stock_match_details';
    protected static $logName = 'stock_match';
    protected static $logUnguarded = true;
    protected static $logOnlyDirty = true;
    protected static $logAttributesToIgnore = ['updated_at'];
    protected $with = [];

    // Meta
    public function getMeta(string $option)
    {
        return Arr::get($this->meta, $option);
    }

    public function getActualQuantityTaxedAttribute()
    {
        return (float) Arr::get($this->actual, 'quantity_taxed', 0);
    }

    public function getActualQuantityNonTaxedAttribute()
    {
        return (float) Arr::get($this->actual, 'quantity_non_taxed', 0);
    }

    public function getBilledQuantityTaxedAttribute()
    {
        return (float) Arr::get($this->billed, 'quantity_taxed', 0);
    }

    public function getBilledQuantityNonTaxedAttribute()
    {
        return (float) Arr::get($this->billed, 'quantity_non_taxed', 0);
    }

    public function stockMatch() : BelongsTo
    {
        return $this->belongsTo(StockMatch::class);
    }

    public function item() : BelongsTo
    {
        return $this->belongsTo(Item::class);
    }

    // Booted
    public static function booted()
    {
    }

    protected static function ensureUpdatable() : void
    {

    }

    // Filters
    public function scopeFilterById(Builder $query, $id) : void
    {
        $query->when($id, function ($q, $id) {
            return $q->where('id', '=', $id);
        });
    }

    public function scopeFilterByUuid(Builder $query, $uuid) : void
    {
        $query->when($uuid, function ($q, $uuid) {
            return $q->where('uuid', '=', $uuid);
        });
    }
}
