<?php

namespace App\Models;

use App\Models\Accounting\Ledger;
use App\Models\Accounting\Transaction;
use App\Models\Accounting\Voucher;
use App\Models\Inventory\Brand;
use App\Models\Inventory\Item;
use App\Models\Inventory\ItemCategory;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;

class Tag extends Model
{
    protected $fillable = [
        'name',
        'slug'
    ];

    public function vouchers()
    {
        return $this->morphedByMany(Voucher::class, 'taggable');
    }

    public function ledgers()
    {
        return $this->morphedByMany(Ledger::class, 'taggable');
    }

    public function items()
    {
        return $this->morphedByMany(Item::class, 'taggable');
    }

    public function itemCategories()
    {
        return $this->morphedByMany(ItemCategory::class, 'taggable');
    }

    public function transactions()
    {
        return $this->morphedByMany(Transaction::class, 'taggable');
    }

    public function contacts()
    {
        return $this->morphedByMany(Contact::class, 'taggable');
    }

    public function brands()
    {
        return $this->morphedByMany(Brand::class, 'taggable');
    }

    public function scopeSearch(Builder $query, $search = null)
    {
        $fuzzy = implode("%", str_split($search));
        $fuzzy = "%$fuzzy%";

        $query->when($search, function ($q) use ($fuzzy) {
            return $q->where(function($q1) use ($fuzzy) {
                $q1->where('name', 'like', $fuzzy)
                ->orWhere('slug', 'like', $fuzzy);
            });
        });
    }
}
