<?php

namespace App\Policies\Accounting;

use App\Models\Accounting\Ledger;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class LedgerPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function viewAny(User $user)
    {
        return $user->can('list-ledger');
    }

    /**
     * Determine whether the user can view reports.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function report(User $user)
    {
        return $user->can('access-ledger-report');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Ledger  $ledger
     * @return mixed
     */
    public function view(User $user, Ledger $ledger)
    {
        return $user->can('list-ledger');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $user->can('create-ledger');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Ledger  $ledger
     * @return mixed
     */
    public function update(User $user, Ledger $ledger)
    {
        return $user->can('edit-ledger');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Ledger  $ledger
     * @return mixed
     */
    public function delete(User $user, Ledger $ledger)
    {
        return $user->can('delete-ledger');
    }

    /**
     * Determine whether the user can restore the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Ledger  $ledger
     * @return mixed
     */
    public function restore(User $user, Ledger $ledger)
    {
        //
    }

    /**
     * Determine whether the user can permanently delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Ledger  $ledger
     * @return mixed
     */
    public function forceDelete(User $user, Ledger $ledger)
    {
        //
    }
}
