<?php

namespace App\Policies\Accounting;

use App\Enums\VoucherType;
use App\Models\Accounting\Voucher;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class VoucherPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function viewAny(User $user)
    {
        return $user->can('list-' . request('type'));
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function view(User $user, Voucher $voucher)
    {
        return $user->can('list-' . request('type'));
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $user->can('create-' . request('type'));
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function update(User $user, Voucher $voucher)
    {
        if (! $user->hasRole('admin') && $voucher->user_id != $user->id) {
            return false;
        }

        return $user->can('edit-' . request('type'));
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function delete(User $user, Voucher $voucher)
    {
        if (! $user->hasRole('admin') && $voucher->user_id != $user->id) {
            return false;
        }

        return $user->can('delete-' . request('type'));
    }

    /**
     * Determine whether the user can follow up the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function followUp(User $user)
    {
        if (! in_array(request('type'), [VoucherType::SALE_ENQUIRY])) {
            return false;
        }

        return $user->can('create-' . request('type'));
    }

    /**
     * Determine whether the user can restore the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function restore(User $user, Voucher $voucher)
    {
        //
    }

    /**
     * Determine whether the user can permanently delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Accounting\Voucher  $voucher
     * @return mixed
     */
    public function forceDelete(User $user, Voucher $voucher)
    {
        //
    }
}
