<?php

namespace App\Policies\Inventory;

use App\Models\Inventory\ItemCategory;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class ItemCategoryPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can get prerequisites.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function preRequisite(User $user)
    {
        return $user->can('create-item-category') || $user->can('edit-item-category');
    }

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function viewAny(User $user)
    {
        return $user->can('list-item-category');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\ItemCategory  $item_category
     * @return mixed
     */
    public function view(User $user)
    {
        return $user->can('list-item-category');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $user->can('create-item-category');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\ItemCategory  $item_category
     * @return mixed
     */
    public function update(User $user, ItemCategory $item_category)
    {
        return $user->can('edit-item-category');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\ItemCategory  $item_category
     * @return mixed
     */
    public function delete(User $user, ItemCategory $item_category)
    {
        return $user->can('delete-item-category');
    }

    /**
     * Determine whether the user can restore the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\ItemCategory  $item_category
     * @return mixed
     */
    public function restore(User $user, ItemCategory $item_category)
    {
        //
    }

    /**
     * Determine whether the user can permanently delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\ItemCategory  $item_category
     * @return mixed
     */
    public function forceDelete(User $user, ItemCategory $item_category)
    {
        //
    }
}