<?php

namespace App\Policies\Inventory;

use App\Models\Inventory\Item;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class ItemPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can get prerequisites.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function preRequisite(User $user)
    {
        return $user->can('create-item') || $user->can('edit-item');
    }

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function viewAny(User $user)
    {
        return $user->can('list-item');
    }

    /**
     * Determine whether the user can view reports.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function report(User $user)
    {
        return $user->can('access-item-report');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\Item  $item
     * @return mixed
     */
    public function view(User $user)
    {
        return $user->can('list-item');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $user->can('create-item');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\Item  $item
     * @return mixed
     */
    public function update(User $user, Item $item)
    {
        return $user->can('edit-item');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\Item  $item
     * @return mixed
     */
    public function delete(User $user, Item $item)
    {
        return $user->can('delete-item');
    }

    /**
     * Determine whether the user can restore the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\Item  $item
     * @return mixed
     */
    public function restore(User $user, Item $item)
    {
        //
    }

    /**
     * Determine whether the user can permanently delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\Item  $item
     * @return mixed
     */
    public function forceDelete(User $user, Item $item)
    {
        //
    }
}
