<?php

namespace App\Policies\Inventory;

use App\Models\Inventory\StockMatch;
use App\Models\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class StockMatchPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can get prerequisites.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function preRequisite(User $user)
    {
        return $user->can('create-stock-match') || $user->can('edit-stock-match');
    }

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function viewAny(User $user)
    {
        return $user->can('list-stock-match');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\StockMatch  $item
     * @return mixed
     */
    public function view(User $user)
    {
        return $user->can('list-stock-match');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $user->can('create-stock-match');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\StockMatch  $item
     * @return mixed
     */
    public function update(User $user, StockMatch $item)
    {
        return $user->can('edit-stock-match');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\StockMatch  $item
     * @return mixed
     */
    public function delete(User $user, StockMatch $item)
    {
        return $user->can('delete-stock-match');
    }

    /**
     * Determine whether the user can restore the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\StockMatch  $item
     * @return mixed
     */
    public function restore(User $user, StockMatch $item)
    {
        //
    }

    /**
     * Determine whether the user can permanently delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\Inventory\StockMatch  $item
     * @return mixed
     */
    public function forceDelete(User $user, StockMatch $item)
    {
        //
    }
}
