<?php

namespace App\Repositories\Accounting;

use App\Models\Accounting\FollowUp;
use App\Helpers\ArrHelper;
use App\Helpers\CalHelper;
use App\Models\Accounting\Voucher;
use App\Repositories\Accounting\VoucherRepository;
use Illuminate\Support\Arr;
use Illuminate\Validation\ValidationException;

class FollowUpRepository
{
    protected $follow_up;
    protected $voucher;

    /**
     * Instantiate a new instance
     * @return void
     */
    public function __construct(
        FollowUp $follow_up,
        VoucherRepository $voucher
    ) {
        $this->follow_up = $follow_up;
        $this->voucher = $voucher;
    }

    /**
     * Create a new follow up
     */
    public function create($uuid) : FollowUp
    {
        $voucher = $this->voucher->findByUuidOrFail($uuid, 'message');

        $follow_up = $this->follow_up->forceCreate($this->formatParams($voucher->id));

        return $follow_up;
    }

    /**
     * Prepare given params for inserting into database
     * @param int $voucher_id
     * @param uuid $uuid
     */
    private function formatParams($voucher_id, $uuid = null) : array
    {
        $status = ArrHelper::searchByKey(ArrHelper::getTransList('statuses', 'enquiry'), 'uuid', request('status.uuid'));

        if (! $status) {
            throw ValidationException::withMessages(['status' => trans('general.invalid_input')]);
        }

        $formatted = [
            'voucher_id' => $voucher_id,
            'date'       => CalHelper::toDate(request('date')),
            'next_date'  => CalHelper::toDate(request('next_date')),
            'remarks'    => request('remarks'),
            'status'     => Arr::get($status, 'uuid')
        ];

        if (! $uuid) {
            $formatted['user_id'] = \Auth::id();
        }

        return $formatted;
    }
}
