<?php

namespace App\Repositories;

use App\Http\Resources\Accounting\LedgerCollection;
use App\Http\Resources\Accounting\VoucherSummaryCollection;
use App\Http\Resources\ContactCollection;
use App\Http\Resources\Inventory\ItemCollection;
use App\Http\Resources\UserCollection;
use App\Models\Accounting\Ledger;
use App\Models\Accounting\Voucher;
use App\Models\Contact;
use App\Models\Inventory\Item;
use App\Models\User;
use App\Traits\CustomModelOption;

class SearchRepository
{
    use CustomModelOption;

    protected $user;
    protected $item;
    protected $ledger;
    protected $contact;
    protected $voucher;

    /**
     * Instantiate a new instance
     * @return void
     */
    public function __construct(
        User $user,
        Item $item,
        Ledger $ledger,
        Contact $contact,
        Voucher $voucher
    ) {
        $this->user = $user;
        $this->item = $item;
        $this->ledger = $ledger;
        $this->contact = $contact;
        $this->voucher = $voucher;
    }

    /**
     * Search term
     */
    public function search() : array
    {
        if (strlen(request()->query('q')) < 3) {
            return [];
        }

        $term = request()->query('q');

        $per_page = $this->getPerPage();

        $users = new UserCollection($this->user->filterByKeyword($term)->orderBy('created_at', 'desc')->orderBy('name', 'asc')->take($per_page)->get());

        $items = new ItemCollection($this->item->search($term)->orWhereHas('tags', function($q) use ($term) {
            $q->where('name', 'like', '%'.$term.'%');
        })->orderBy('name', 'asc')->take($per_page)->get());

        $ledgers = new LedgerCollection($this->ledger->search($term)->orWhereHas('tags', function($q) use ($term) {
            $q->where('name', 'like', '%'.$term.'%');
        })->orderBy('name', 'asc')->take($per_page)->get());

        $contacts = new ContactCollection($this->contact->search($term)->orWhereHas('tags', function($q) use ($term) {
            $q->where('name', 'like', '%'.$term.'%');
        })->orderBy('name', 'asc')->take($per_page)->get());

        $vouchers = new VoucherSummaryCollection($this->voucher->where('type', 'like', '%'.$term.'%')->orWhere('code_number', 'like', '%'.$term.'%')->orWhereHas('ledger', function($q) use ($term) {
            $q->where('name', 'like', '%'.$term.'%');
        })->orWhereHas('tags', function($q) use ($term) {
            $q->where('name', 'like', '%'.$term.'%');
        })->orderBy('created_at', 'desc')->take($per_page)->get());

        return compact('users', 'items', 'ledgers', 'contacts', 'vouchers');
    }
}
