<?php

namespace App\Traits;

use App\Models\Contact;
use Illuminate\Support\Arr;
use Illuminate\Validation\ValidationException;

trait HasContact
{
    private function getContact()
    {
        $contact = Contact::whereUuid(request('contact.uuid'))->first();

        if (! $contact) {
            throw ValidationException::withMessages(['message' => trans('global.could_not_find', ['attribute' => trans('contact.contact')])]);
        }

        return $contact;
    }

    public function newContact()
    {
        $query = Contact::whereMobile(request('contact.mobile'));

        if (request('contact.email')) {
            $query->orWhere('email', request('contact.email'));
        }

        $contact = $query->first();

        if (! $contact) {
            $contact = $this->create();
        } else {
            $contact->is_primary = 1;
            $contact->save();
        }

        $this->contacts()->save($contact);
    }

    private function create()
    {
        return Contact::forceCreate([
            'name'         => $this->name,
            'alias'        => request('contact.alias'),
            'designation'  => request('contact.designation'),
            'phone'        => request('contact.phone'),
            'mobile'       => request('contact.mobile'),
            'alt_mobile'   => request('contact.alt_mobile'),
            'email'        => request('contact.email'),
            'alt_email'    => request('contact.alt_email'),
            'address'      => array(
                'address_line1' => request('contact.address_line1'),
                'address_line2' => request('contact.address_line2'),
                'city'          => request('contact.city'),
                'state'         => request('contact.state'),
                'zipcode'       => request('contact.zipcode'),
                'country'       => request('contact.country')
            ),
            'is_primary' => true,
            'meta' => array()
        ]);
    }

    public function addContact()
    {
        $contact = $this->getContact();

        if ($this->contacts->where('id', $contact->id)->count()) {
            return;
        }

        $this->contacts()->save($contact);
    }

    public function removeContact()
    {
        $contact = $this->getContact();

        if (! $this->contacts->where('id', $contact->id)->count()) {
            return;
        }

        if ($this->contacts->where('id', $contact->id)->where('is_primary', 1)->count()) {
            throw ValidationException::withMessages(['message' => trans('global.cannot_delete_default', ['attribute' => trans('contact.contact')])]);
        }

        $this->contacts()->detach([$contact->id]);
    }
}
