<?php

namespace App\Traits;

use Illuminate\Database\Eloquent\Builder;

trait HasParent
{
    private $descendents = [];
    private $ancestors = [];

    public function children()
    {
        return $this->hasMany(self::class, 'parent_id');
    }

    public function nestedChildren()
    {
        return $this->children()->with('nestedChildren');
    }

    public function parent()
    {
        return $this->belongsTo(self::class, 'parent_id');
    }

    public function nestedParents()
    {
        return $this->belongsTo(self::class, 'parent_id')->with('nestedParents');
    }

    public function descendents()
    {
        if ($this->children) {
            $this->collectDescendents($this->children);
        }

        return collect($this->descendents);
    }

    private function collectDescendents($children)
    {
        foreach ($children as $child) {
            $this->descendents[] = $child;
            if ($child->children) {
                $this->collectDescendents($child->children);
            }
        }
    }

    public function ancestors()
    {
        if ($this->parent) {
            $this->collectAncestors($this->parent);
        }

        return collect($this->ancestors);
    }

    private function collectAncestors($parent)
    {
        $this->ancestors[] = $parent;
        if ($parent->parent) {
            $this->collectAncestors($parent->parent);
        }
    }

    public function ancestorsInfo()
    {
        if ($this->parent) {
            $this->collectAncestorsInfo($this->parent);
        }

        return collect($this->ancestors);
    }

    private function collectAncestorsInfo($parent)
    {
        $this->ancestors[] = array('uuid' => $parent->uuid, 'name' => $parent->name);
        if ($parent->parent) {
            $this->collectAncestorsInfo($parent->parent);
        }
    }

    public function topAncestor()
    {
        if ($this->parent) {
            $this->getTopAncestor($this->parent);
        }

        return $this->ancestor;
    }

    private function getTopAncestor($parent)
    {
        $this->ancestor = $parent;
        if ($parent->parent) {
            $this->getTopAncestor($parent->parent);
        }
    }
}