<?php

namespace App\Traits;

use App\Enums\LedgerGroup;
use App\Enums\TransactionType;

trait TransactionConstraints
{
    /**
     * Get primary ledger multiplier
     */
    private function getPrimaryLedgerMultiplier($type) : int
    {
        $value = 1;

        if (in_array($type, [TransactionType::PAYMENT, TransactionType::CONTRA])) {
            $value = -1;
        }

        return $value;
    }

    /**
     * Get secondary ledger multiplier
     */
    private function getSecondaryLedgerMultiplier($type, $ledger) : int
    {
        $value = 1;
        $ledger_type = $ledger->type->code;

        if ($type == TransactionType::PAYMENT && $ledger_type == LedgerGroup::SUNDRY_CREDITOR
            || $type == TransactionType::RECEIPT && $ledger_type == LedgerGroup::SUNDRY_DEBTOR
            || $type == TransactionType::PAYMENT && $ledger_type == LedgerGroup::INDIRECT_EXPENSE
        ) {
            $value = -1;
        }

        return $value;
    }

    private function needsPaymentStatusUpdate($type, $ledger)
    {
        if (! in_array($type, [TransactionType::PAYMENT, TransactionType::RECEIPT])) {
            return false;
        }

        $ledger_type = $ledger->type->code;

        if (in_array($ledger_type, [LedgerGroup::SUNDRY_CREDITOR, LedgerGroup::SUNDRY_DEBTOR])) {
            return true;
        }

        return false;
    }
}
