<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateItemCategoriesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('item_categories', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();
            $table->string('name')->nullable();
            $table->string('alias')->nullable();
            $table->string('type')->nullable();
            $table->text('description')->nullable();

            $table->bigInteger('parent_id')->unsigned()->nullable();
            $table->foreign('parent_id')->references('id')->on('item_categories')->onDelete('cascade');
            $table->bigInteger('unit_id')->unsigned()->nullable();
            $table->foreign('unit_id')->references('id')->on('units')->onDelete('set null');
            $table->bigInteger('tax_id')->unsigned()->nullable();
            $table->foreign('tax_id')->references('id')->on('taxes')->onDelete('set null');
            $table->bigInteger('margin_id')->unsigned()->nullable();
            $table->foreign('margin_id')->references('id')->on('margins')->onDelete('set null');

            $table->integer('reorder_level')->default(0);
            $table->string('price_calculation_method')->nullable();
            $table->json('variants')->nullable();
            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('item_categories', function (Blueprint $table) {
            $table->dropForeign('item_categories_parent_id_foreign');
            $table->dropForeign('item_categories_unit_id_foreign');
            $table->dropForeign('item_categories_tax_id_foreign');
            $table->dropForeign('item_categories_margin_id_foreign');
        });

        Schema::dropIfExists('item_categories');
    }
}
