<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateItemsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('items', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();
            $table->string('name')->nullable();
            $table->string('alias')->nullable();
            $table->text('description')->nullable();

            $table->bigInteger('item_category_id')->unsigned()->nullable();
            $table->foreign('item_category_id')->references('id')->on('item_categories')->onDelete('cascade');
            $table->bigInteger('brand_id')->unsigned()->nullable();
            $table->foreign('brand_id')->references('id')->on('brands')->onDelete('set null');
            $table->bigInteger('unit_id')->unsigned()->nullable();
            $table->foreign('unit_id')->references('id')->on('units')->onDelete('set null');
            $table->bigInteger('tax_id')->unsigned()->nullable();
            $table->foreign('tax_id')->references('id')->on('taxes')->onDelete('set null');
            $table->bigInteger('margin_id')->unsigned()->nullable();
            $table->foreign('margin_id')->references('id')->on('margins')->onDelete('set null');

            $table->json('identifier')->nullable();
            $table->json('opening')->nullable();
            $table->json('current')->nullable();
            $table->decimal('mrp', 25, 5)->nullable();
            $table->text('warranty')->nullable();
            $table->integer('reorder_level')->default(0);
            $table->string('price_calculation_method')->nullable();
            $table->json('variants')->nullable();
            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('items', function (Blueprint $table) {
            $table->dropForeign('items_item_category_id_foreign');
            $table->dropForeign('items_brand_id_foreign');
            $table->dropForeign('items_unit_id_foreign');
            $table->dropForeign('items_tax_id_foreign');
            $table->dropForeign('items_margin_id_foreign');
        });

        Schema::dropIfExists('items');
    }
}
