<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateVouchersTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('vouchers', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();
            $table->string('type', 20)->nullable();
            $table->string('number_format')->nullable();
            $table->integer('number')->nullable();
            $table->string('code_number')->nullable();
            $table->string('reference_number')->nullable();
            $table->date('date')->nullable();
            $table->date('due_date')->nullable();
            $table->date('delivery_date')->nullable();
            $table->date('expected_delivery_date')->nullable();

            $table->bigInteger('ledger_id')->unsigned()->nullable();
            $table->foreign('ledger_id')->references('id')->on('ledgers')->onDelete('cascade');
            $table->bigInteger('contact_id')->unsigned()->nullable();
            $table->foreign('contact_id')->references('id')->on('contacts')->onDelete('cascade');
            $table->bigInteger('referral_id')->unsigned()->nullable();
            $table->foreign('referral_id')->references('id')->on('contacts')->onDelete('set null');
            $table->bigInteger('transport_id')->unsigned()->nullable();
            $table->foreign('transport_id')->references('id')->on('options')->onDelete('set null');
            $table->bigInteger('enquiry_type_id')->unsigned()->nullable();
            $table->foreign('enquiry_type_id')->references('id')->on('options')->onDelete('set null');
            $table->bigInteger('enquiry_source_id')->unsigned()->nullable();
            $table->foreign('enquiry_source_id')->references('id')->on('options')->onDelete('set null');
            $table->nullableMorphs('linkable');

            $table->string('tracking_number')->nullable();
            $table->boolean('is_non_taxed')->default(0);
            $table->string('status', 20)->nullable();
            $table->string('payment_status', 20)->nullable();
            $table->decimal('amount', 25, 5)->default(0);
            $table->decimal('shipping', 25, 5)->default(0);
            $table->decimal('round_off', 25, 5)->default(0);
            $table->decimal('total', 25, 5)->default(0);
            $table->decimal('paid', 25, 5)->default(0);
            $table->json('discount')->nullable();
            $table->json('tax')->nullable();

            $table->text('subject')->nullable();
            $table->text('description')->nullable();

            $table->text('note')->nullable();
            $table->text('terms')->nullable();
            $table->text('memo')->nullable();
            $table->text('bank_details')->nullable();
            $table->json('info')->nullable();

            $table->bigInteger('user_id')->unsigned()->nullable();
            $table->foreign('user_id')->references('id')->on('users')->onDelete('set null');

            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('vouchers', function (Blueprint $table) {
            $table->dropForeign('vouchers_ledger_id_foreign');
            $table->dropForeign('vouchers_contact_id_foreign');
            $table->dropForeign('vouchers_referral_id_foreign');
            $table->dropForeign('vouchers_user_id_foreign');
            $table->dropForeign('vouchers_transport_id_foreign');
            $table->dropForeign('vouchers_enquiry_type_id_foreign');
            $table->dropForeign('vouchers_enquiry_source_id_foreign');
        });

        Schema::dropIfExists('vouchers');
    }
}
