<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateTransactionsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('transactions', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();
            $table->string('type', 20)->nullable();
            $table->string('number_format')->nullable();
            $table->integer('number')->nullable();
            $table->string('code_number')->nullable();
            $table->date('date')->nullable();
            $table->boolean('is_non_taxed')->default(0);

            $table->bigInteger('ledger_id')->unsigned()->nullable();
            $table->foreign('ledger_id')->references('id')->on('ledgers')->onDelete('cascade');

            $table->boolean('direction')->default(0);
            $table->decimal('amount', 25, 5)->default(0);

            $table->text('description')->nullable();

            $table->bigInteger('user_id')->unsigned()->nullable();
            $table->foreign('user_id')->references('id')->on('users')->onDelete('set null');

            $table->boolean('is_cancelled')->default(0);
            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('transactions', function (Blueprint $table) {
            $table->dropForeign('transactions_ledger_id_foreign');
            $table->dropForeign('transactions_user_id_foreign');
        });

        Schema::dropIfExists('transactions');
    }
}
