<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateJobCardsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('job_cards', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();

            $table->bigInteger('job_type_id')->unsigned()->nullable();
            $table->foreign('job_type_id')->references('id')->on('options')->onDelete('cascade');

            $table->bigInteger('contact_id')->unsigned()->nullable();
            $table->foreign('contact_id')->references('id')->on('contacts')->onDelete('cascade');

            $table->uuid('date')->nullable();
            $table->text('item_description')->nullable();
            $table->text('issue_description')->nullable();
            $table->dateTime('in_datetime')->nullable();
            $table->dateTime('estimated_out_datetime')->nullable();
            $table->dateTime('out_datetime')->nullable();
            $table->decimal('estimated_amount', 25, 5)->default(0);
            $table->decimal('billing_amount', 25, 5)->default(0);
            $table->text('memo')->nullable();

            $table->bigInteger('user_id')->unsigned()->nullable();
            $table->foreign('user_id')->references('id')->on('users')->onDelete('set null');

            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('job_cards', function (Blueprint $table) {
            $table->dropForeign('job_cards_job_type_id_foreign');
            $table->dropForeign('job_cards_contact_id_foreign');
            $table->dropForeign('job_cards_user_id_foreign');
        });

        Schema::dropIfExists('job_cards');
    }
}
