<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateServiceRequestsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('service_requests', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid')->nullable();
            $table->string('type')->nullable();

            $table->bigInteger('job_card_id')->unsigned()->nullable();
            $table->foreign('job_card_id')->references('id')->on('job_cards')->onDelete('cascade');

            $table->bigInteger('ledger_id')->unsigned()->nullable();
            $table->foreign('ledger_id')->references('id')->on('ledgers')->onDelete('cascade');

            $table->bigInteger('item_id')->unsigned()->nullable();
            $table->foreign('item_id')->references('id')->on('items')->onDelete('cascade');

            $table->string('date')->nullable();
            $table->text('item_description')->nullable();
            $table->text('issue_description')->nullable();
            $table->json('follow_up')->nullable();
            $table->date('estimated_resolution_date')->nullable();
            $table->date('resolution_date')->nullable();
            $table->text('resolution_description')->nullable();
            $table->decimal('estimated_amount', 25, 5)->default(0);
            $table->decimal('billing_amount', 25, 5)->default(0);
            $table->text('memo')->nullable();

            $table->bigInteger('user_id')->unsigned()->nullable();
            $table->foreign('user_id')->references('id')->on('users')->onDelete('set null');

            $table->json('meta')->nullable();
            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::table('service_requests', function (Blueprint $table) {
            $table->dropForeign('service_requests_job_card_id_foreign');
            $table->dropForeign('service_requests_ledger_id_foreign');
            $table->dropForeign('service_requests_item_id_foreign');
            $table->dropForeign('service_requests_user_id_foreign');
        });

        Schema::dropIfExists('service_requests');
    }
}
