<?php

namespace Database\Seeders;

use App\Enums\LedgerGroup;
use App\Models\Accounting\LedgerType;
use Illuminate\Database\Seeder;
use Illuminate\Support\Arr;

class DefaultLedgerTypeSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $default_ledger_types = array(
            array(
                'name' => 'Sundry Debtor',
                'code' => LedgerGroup::SUNDRY_DEBTOR,
                'has_contact' => true,
                'has_account' => true,
            ),
            array(
                'name' => 'Sundry Creditor',
                'code' => LedgerGroup::SUNDRY_CREDITOR,
                'has_contact' => true,
                'has_account' => true,
            ),
            array(
                'name' => 'Cash',
                'code' => LedgerGroup::CASH
            ),
            array(
                'name' => 'Bank Account',
                'code' => LedgerGroup::BANK_ACCOUNT,
                'has_account' => true,
            ),
            array(
                'name' => 'Indirect Expense',
                'code' => LedgerGroup::INDIRECT_EXPENSE,
                'has_contact' => true,
            ),
            array(
                'name' => 'Indirect Income',
                'code' => LedgerGroup::INDIRECT_INCOME,
                'has_contact' => true,
            ),
        );

        foreach ($default_ledger_types as $default_ledger_type) {
            $ledger_type = LedgerType::firstOrCreate([
                'name' => Arr::get($default_ledger_type, 'name')
            ]);

            $ledger_type->alias = Arr::get($default_ledger_type, 'alias');
            $ledger_type->code = Arr::get($default_ledger_type, 'code');
            $meta = $ledger_type->meta;
            $meta['is_default'] = true;
            $meta['has_account'] = (bool) Arr::get($default_ledger_type, 'has_account');
            $meta['has_contact'] = (bool) Arr::get($default_ledger_type, 'has_contact');
            $ledger_type->meta = $meta;
            $ledger_type->save();
        }
    }
}
