import { formatDecimal, addPercentage, getDiscountedPrice, getOriginalPrice, getDiscountedValue, getPercentageAmount } from '@core/utils'

export default {
    components: {
        'ItemTable': () => import("@components/ItemTable" /* webpackChunkName: "app/components/item-table" */ ),
    },
    data() {
        return {
            formData: {
                isNonTaxed: false,
                items: [],
                discounts: [],
                taxes: [],
                total: {}
            },
            formLabels: {},
            areArrayOfObjectsFields: ['items', 'discounts', 'taxes'],
            itemTableConfig: {
                isNonTaxed: false,
                hasCustomItems: true,
                hasQuantity: true,
                hasDiscounts: true,
                showRateWithTax: false,
                showRateWithDiscount: false,
                showRateWithTaxDiscount: false,
                showAmount: true,
                showAmountWithTax: false,
                showAmountWithDiscount: true,
                showAmountWithAllDiscounts: false,
                showAmountWithTaxDiscount: false,
                showTotal: true,
                rateType: 'sale',
            },
            newTaxRowObj: {
                uuid: '',
                tax: null,
                taxable: null,
                amount: '',
                items: [],
            },
        }
    },
    computed: {
        computedConfig() {
            return {
                ...this.itemTableConfig,
                isNonTaxed: this.formData.isNonTaxed,
            }
        },
    },
    methods: {
        formatCurrency(val) {
            return formatDecimal(val, this.vars.defaultCurrency.decimal)
        },
        isNonTaxedChanged() {
            this.formData.taxes = _.cloneDeep(this.initialFormData.taxes)
            if(this.formData.isNonTaxed) {
                this.itemTableConfig = {
                    ...this.itemTableConfig,
                    showAmount: true,
                    showAmountWithDiscount: true,
                }
            }
            this.updateTotal()
        },
        getOuterDiscountedAmount(amount, reverse = false) {
            if(this.formData.discounts && this.formData.discounts.length) {
                let discounts = _.cloneDeep(this.formData.discounts)
                discounts = reverse ? discounts.reverse() : discounts
                discounts.forEach(discount => {
                    if(discount.value) {
                        if(reverse) {
                            amount = this.formatCurrency( getOriginalPrice(amount, discount.value) )
                        } else {
                            let disVal = getDiscountedValue(amount, discount.value)
                            disVal = this.formatCurrency( disVal )
                            amount = this.formatCurrency( amount - disVal )
                            // amount = this.formatCurrency( amount - this.formatCurrency( getDiscountedValue(amount, discount.value) ) )
                        }
                    }
                })
            }
            return amount
        },
        updateTotal: _.debounce(function() {
            if(!this.formData) {
                return
            }
            if(this.formData.items.length === 0) {
                this.formData.total.quantity = 0
                this.formData.total.rate = 0
                this.formData.total.rateWithTax = 0
                this.formData.total.rateWithDiscount = 0
                this.formData.total.rateWithTaxDiscount = 0
                this.formData.total.amount = 0
                this.formData.total.amountWithTax = 0
                this.formData.total.amountWithDiscount = 0
                this.formData.total.amountWithTaxDiscount = 0

                this.formData.total.amountWithAllDiscounts = 0
                this.formData.total.amountTotal = 0

                this.formData.total.discountsTotalAmount = 0
                this.formData.total.taxesTotalAmount = 0
                this.formData.total.voucherLevelTaxesTotalAmount = 0
                this.formData.total.totalAmount = 0

                return
            }

            let quantity = 0,
                rate = 0,
                rateWithTax = 0,
                rateWithDiscount = 0,
                rateWithTaxDiscount = 0,
                amount = 0,
                amountWithTax = 0,
                amountWithDiscount = 0,
                amountWithTaxDiscount = 0,
                amountWithAllDiscounts = 0,
                amountTotal = 0

            this.formData.items.forEach(item => {
                quantity = quantity + Number(item.quantity)

                rate = rate + Number(item.rate)

                rateWithTax = rateWithTax + Number(item.rateWithTax)

                rateWithDiscount = rateWithDiscount + Number(item.rateWithDiscount)

                rateWithTaxDiscount = rateWithTaxDiscount + Number(item.rateWithTaxDiscount)

                amount = amount + Number(item.amount)
                amountWithTax = amountWithTax + Number(item.amountWithTax)

                amountWithDiscount = amountWithDiscount + Number(item.amountWithDiscount)

                amountWithTaxDiscount = amountWithTaxDiscount + Number(item.amountWithTaxDiscount)

                item.amountWithAllDiscounts = this.formatCurrency( this.formatCurrency( this.getOuterDiscountedAmount( this.formatCurrency( item.amountWithDiscount ) ) ) )

                item.amountTotal = this.formatCurrency( addPercentage(item.amountWithAllDiscounts, item.tax ? item.tax.value : 0) )

                amountWithAllDiscounts = amountWithAllDiscounts + Number(item.amountWithAllDiscounts)

                amountTotal = amountTotal + Number(item.amountTotal)
            })


            this.formData.total.quantity = quantity
            this.formData.total.rate = this.formatCurrency(rate)
            this.formData.total.rateWithTax = this.formatCurrency(rateWithTax)
            this.formData.total.rateWithDiscount = this.formatCurrency(rateWithDiscount)
            this.formData.total.rateWithTaxDiscount = this.formatCurrency(rateWithTaxDiscount)
            this.formData.total.amount = this.formatCurrency(amount)
            this.formData.total.amountWithTax = this.formatCurrency(amountWithTax)
            this.formData.total.amountWithDiscount = this.formatCurrency(amountWithDiscount)
            this.formData.total.amountWithTaxDiscount = this.formatCurrency(amountWithTaxDiscount)

            this.formData.total.amountWithAllDiscounts = this.formatCurrency(amountWithAllDiscounts)
            this.formData.total.amountTotal = amountTotal = this.formatCurrency(amountTotal)

            if(this.formData.discounts) {
                this.formData.total.discountsTotalAmount = this.formData.discounts.reduce((a, b) => Number(a) + (b ? Number(b.amount) || 0 : 0), 0)
            }

            if(!this.formData.isNonTaxed) {
                let taxes = _.cloneDeep(this.formData.taxes)

                this.formData.items.forEach(item => {
                    if(item.tax) {
                        let taxIndex = taxes.findIndex(t => t.tax && t.tax.name === item.tax.name && t.tax.value === item.tax.value)

                        if(taxIndex === -1) {
                            taxIndex = taxes.length
                            const newObj = _.cloneDeep(this.newTaxRowObj)
                            newObj.uuid = uuid()
                            newObj.taxable = 0
                            newObj.tax = Object.assign({}, item.tax)
                            taxes.unshift(newObj)
                        }
                    }
                })

                let toDelete = []
                taxes.forEach((taxObj, index) => {

                    if(!taxObj.tax || taxObj.tax.voucherLevelTax) {

                        taxes[index].amount = this.formatCurrency( getPercentageAmount(this.formData.total.amountWithAllDiscounts, taxObj.tax.value) )

                    } else {

                        let items = this.formData.items.filter(item => item.tax && item.tax.name === taxObj.tax.name && item.tax.value === taxObj.tax.value)

                        if(items.length) {
                            taxes[index].taxable = items.reduce((a, b) => Number(a) + (b ? Number(b.amountWithAllDiscounts) || 0 : 0), 0)

                            taxes[index].amount = this.formatCurrency( getPercentageAmount(taxes[index].taxable, taxObj.tax.value) )

                        } else {
                            toDelete.push(index)
                        }

                    }
                })

                toDelete.forEach(i => {
                    taxes.splice(i, 1)
                })

                this.formData.taxes = _.cloneDeep(taxes)
                this.formData.total.taxesTotalAmount = this.formData.taxes.reduce((a, b) => Number(a) + (b ? Number(b.amount) || 0 : 0), 0)
                this.formData.total.voucherLevelTaxesTotalAmount = this.formData.taxes.filter(t => t.tax && t.tax.voucherLevelTax).reduce((a, b) => Number(a) + (b ? Number(b.amount) || 0 : 0), 0)
            } else {
                this.formData.total.taxesTotalAmount = 0
                this.formData.total.voucherLevelTaxesTotalAmount = 0
            }

            // let totalAmountBeforeRoundOff = Number( Number(this.formData.total.amountWithDiscount) - Number(this.formData.total.discountsTotalAmount) + Number(this.formData.total.taxesTotalAmount) + Number(this.formData.shipping))
            let totalAmountBeforeRoundOff = Number( Number(this.formData.total.amountTotal) + Number(this.formData.total.voucherLevelTaxesTotalAmount) + Number(this.formData.shipping))

            if(!this.formData.roundOffForced) {
                this.formData.total.totalAmount = formatDecimal(totalAmountBeforeRoundOff, 0)
                this.formData.roundOff = this.formatCurrency(Number(Number(this.formData.total.totalAmount) - totalAmountBeforeRoundOff))
            } else {
                this.formData.total.totalAmount = this.formatCurrency(Number( totalAmountBeforeRoundOff + Number(this.formData.roundOff) ))
            }
        }, 500),
        updateRoundOff() {
            this.formData.roundOffForced = true
            this.updateTotal()
        },
        updateConfig(config) {
            this.itemTableConfig = {
                ...this.itemTableConfig,
                ...config
            }
        },
        initItemTableConfig(configs) {
            this.itemTableConfig = {
                ...this.itemTableConfig,
                showRateWithTax: configs.showRateWithTaxColumn,
                showRateWithDiscount: configs.showRateWithDiscountColumn,
                showRateWithTaxDiscount: configs.showRateWithTaxDiscountColumn,
                showAmount: configs.showAmountColumn,
                showAmountWithTax: configs.showAmountWithTaxColumn,
                showAmountWithDiscount: configs.showAmountWithDiscountColumn,
                showAmountWithAllDiscounts: configs.showAmountWithAllDiscountsColumn,
                showAmountWithTaxDiscount: configs.showAmountWithTaxDiscountColumn,
                showAmountTotal: configs.showAmountTotalColumn,
            }
        },
        initFormLabels(localeStr, hasTaxes = false, hasDiscounts = false) {

            if(!localeStr) {
                return
            }

            this.formLabels.items = {
                item: $t('inventory.item.item'),
                items: $t('inventory.item.items'),
                description: $t(`${localeStr}.props.description`),
                quantity: $t(`${localeStr}.props.quantity`),
                rate: $t(`${localeStr}.props.rate`),
                unit: $t('setting.unit.unit'),
                per: $t('setting.unit.per'),
                isNonTaxed: $t(`${localeStr}.props.is_non_taxed`),
                tax: $t('setting.tax.tax'),
                rateWithTax: $t(`${localeStr}.props.rate_with_tax`),
                discount: $t(`${localeStr}.props.discount`),
                rateWithDiscount: $t(`${localeStr}.props.rate_with_discount`),
                rateWithTaxDiscount: $t(`${localeStr}.props.rate_with_tax_discount`),
                amount: $t(`${localeStr}.props.amount`),
                amountWithTax: $t(`${localeStr}.props.amount_with_tax`),
                amountWithDiscount: $t(`${localeStr}.props.amount_with_discount`),
                amountWithAllDiscounts: $t(`${localeStr}.props.amount_with_all_discounts`),
                amountWithTaxDiscount: $t(`${localeStr}.props.amount_with_tax_discount`),
                amountTotal: $t(`${localeStr}.props.amount_total`),
                customItem: $t(`${localeStr}.props.custom_item`),
                description: $t(`${localeStr}.props.description`),
                total: $t(`${localeStr}.props.total`),

                heading: {
                    items: $t(`${localeStr}.table_heading.items`),
                    quantity: $t(`${localeStr}.table_heading.quantity`),
                    rate: $t(`${localeStr}.table_heading.rate`),
                    per: $t(`${localeStr}.table_heading.per`),
                    isNonTaxed: $t(`${localeStr}.table_heading.is_non_taxed`),
                    isFulfilled: $t(`${localeStr}.table_heading.is_fulfilled`),
                    tax: $t(`${localeStr}.table_heading.tax`),
                    rateWithTax: $t(`${localeStr}.table_heading.rate_with_tax`),
                    discount: $t(`${localeStr}.table_heading.discount`),
                    rateWithDiscount: $t(`${localeStr}.table_heading.rate_with_discount`),
                    rateWithTaxDiscount: $t(`${localeStr}.table_heading.rate_with_tax_discount`),
                    amount: $t(`${localeStr}.table_heading.amount`),
                    amountWithTax: $t(`${localeStr}.table_heading.amount_with_tax`),
                    amountWithDiscount: $t(`${localeStr}.table_heading.amount_with_discount`),
                    amountWithAllDiscounts: $t(`${localeStr}.table_heading.amount_with_all_discounts`),
                    amountWithTaxDiscount: $t(`${localeStr}.table_heading.amount_with_tax_discount`),
                    amountTotal: $t(`${localeStr}.table_heading.amount_total`),
                }
            }

            if(hasTaxes) {
                this.formLabels.taxes = {
                    tax: $t('setting.tax.tax'),
                    taxes: $t('setting.tax.taxes'),
                    value: $t('setting.tax.props.value'),
                    amount: $t('setting.tax.props.amount'),
                    heading: {
                        taxes: $t(`${localeStr}.table_heading.taxes`),
                        taxValue: $t(`${localeStr}.table_heading.tax_value`),
                        taxAmount: $t(`${localeStr}.table_heading.tax_amount`),
                    }
                }
            }

            if(hasDiscounts) {
                this.formLabels.discounts = {
                    discount: $t('setting.discount.discount'),
                    discounts: $t('setting.discount.discounts'),
                    name: $t('setting.discount.props.name'),
                    value: $t('setting.discount.props.value'),
                    amount: $t('setting.discount.props.amount'),
                    total: $t(`${localeStr}.props.total`),
                    heading: {
                        discounts: $t(`${localeStr}.table_heading.discounts`),
                        discountValue: $t(`${localeStr}.table_heading.discount_value`),
                        discountAmount: $t(`${localeStr}.table_heading.discount_amount`),
                    }
                }
            }
        },
    },
}
