import { getOptionRoutes } from '../config/module-config'

export default [
    {
        path: 'bills',
        name: 'appPurchaseBill',
        redirect: { name: 'appPurchaseBillList' },
        meta: {
            title: 'purchase.bill.bills',
            hideChildren: true,
            permissions: ['list-purchase', 'create-purchase', 'edit-purchase']
        },
        component: {
            template: '<router-view></router-view>'
        },
        children: [
            {
                path: '',
                name: 'appPurchaseBillList',
                meta: {
                    trans: 'global.list',
                    title: 'purchase.bill.bills',
                    permissions: ['list-purchase']
                },
                component: () => import('@views/app/purchase/bill/index' /* webpackChunkName: "app/purchase/bill/index" */),
            },


            {
                path: 'config',
                name: 'appPurchaseBillConfig',
                redirect: { name: 'appPurchaseBillConfigGeneral' },
                meta: {
                    title: 'config.config',
                    permissions: ['access-purchase-config'],
                    isConfigRoute: true,
                },
                component: () => import('@views/app/purchase/bill/config/index' /* webpackChunkName: "app/purchase/bill/config/index" */ ),
                children: [{
                        path: '',
                        name: 'appPurchaseBillConfigGeneral',
                        meta: {
                            title: 'config.general',
                        },
                        component: () => import('@views/app/purchase/bill/config/general' /* webpackChunkName: "app/purchase/bill/config/general" */ ),
                    },
                    getOptionRoutes({
                        path: 'transports',
                        entityTitle: 'setting.transport.transport',
                        entitiesTitle: 'setting.transport.transports',
                        entityDescription: 'setting.transport.module_description',
                        routeNamePrefix: 'appPurchaseBillConfigTransport',
                        permissionRequired: 'access-purchase-config',
                        optionType: 'transport',
                        hasSlug: false,
                    }),
                ]
            },


            {
                path: 'add',
                name: 'appPurchaseBillAdd',
                meta: {
                    trans: 'global.add',
                    title: 'purchase.bill.bill',
                    permissions: ['create-purchase']
                },
                component: () => import('@views/app/purchase/bill/add' /* webpackChunkName: "app/purchase/bill/add" */),
            },
            {
                path: ':uuid/edit',
                name: 'appPurchaseBillEdit',
                meta: {
                    trans: 'global.edit',
                    title: 'purchase.bill.bill',
                    permissions: ['edit-purchase']
                },
                component: () => import('@views/app/purchase/bill/edit' /* webpackChunkName: "app/purchase/bill/edit" */),
            },
            {
                path: ':uuid/duplicate',
                name: 'appPurchaseBillDuplicate',
                meta: {
                    trans: 'global.add',
                    title: 'purchase.bill.bill',
                    permissions: ['create-purchase']
                },
                component: () => import('@views/app/purchase/bill/edit' /* webpackChunkName: "app/purchase/bill/edit" */),
            },
            {
                path: ':uuid',
                name: 'appPurchaseBillView',
                meta: {
                    trans: 'global.view',
                    title: 'purchase.bill.bill',
                    permissions: ['list-purchase']
                },
                component: () => import('@views/app/purchase/bill/view' /* webpackChunkName: "app/purchase/bill/view" */ ),
            },
        ]
    },
]
