import { getOptionRoutes } from '../config/module-config'

export default [{
        path: 'orders',
        name: 'appPurchaseOrder',
        redirect: {
            name: 'appPurchaseOrderList'
        },
        meta: {
            title: 'purchase.order.orders',
            hideChildren: true,
            permissions: ['list-purchase-order', 'create-purchase-order', 'edit-purchase-order'],
        },
        component: {
            template: '<router-view></router-view>'
        },
        children: [{
                path: '',
                name: 'appPurchaseOrderList',
                meta: {
                    trans: 'global.list',
                    title: 'purchase.order.orders',
                    permissions: ['list-purchase-order']
                },
                component: () => import('@views/app/purchase/order/index' /* webpackChunkName: "app/purchase/order/index" */ ),
            },


            {
                path: 'config',
                name: 'appPurchaseOrderConfig',
                redirect: { name: 'appPurchaseOrderConfigGeneral' },
                meta: {
                    title: 'config.config',
                    permissions: ['access-purchase-order-config'],
                    isConfigRoute: true,
                },
                component: () => import('@views/app/purchase/order/config/index' /* webpackChunkName: "app/purchase/order/config/index" */ ),
                children: [{
                        path: '',
                        name: 'appPurchaseOrderConfigGeneral',
                        meta: {
                            title: 'config.general',
                        },
                        component: () => import('@views/app/purchase/order/config/general' /* webpackChunkName: "app/purchase/order/config/general" */ ),
                    }, {
                        path: 'print',
                        name: 'appPurchaseOrderConfigPrint',
                        meta: {
                            title: 'config.print.print',
                        },
                        component: () => import('@views/app/purchase/order/config/print' /* webpackChunkName: "app/purchase/order/config/print" */ ),
                    },
                    getOptionRoutes({
                        path: 'transports',
                        entityTitle: 'setting.transport.transport',
                        entitiesTitle: 'setting.transport.transports',
                        entityDescription: 'setting.transport.module_description',
                        routeNamePrefix: 'appPurchaseOrderConfigTransport',
                        permissionRequired: 'access-purchase-order-config',
                        optionType: 'transport',
                        hasSlug: false,
                    }),
                ]
            },


            {
                path: 'add',
                name: 'appPurchaseOrderAdd',
                meta: {
                    trans: 'global.add',
                    title: 'purchase.order.order',
                    permissions: ['create-purchase-order']
                },
                component: () => import('@views/app/purchase/order/add' /* webpackChunkName: "app/purchase/order/add" */ ),
            },
            {
                path: ':uuid/edit',
                name: 'appPurchaseOrderEdit',
                meta: {
                    trans: 'global.edit',
                    title: 'purchase.order.order',
                    permissions: ['edit-purchase-order']
                },
                component: () => import('@views/app/purchase/order/edit' /* webpackChunkName: "app/purchase/order/edit" */ ),
            },
            {
                path: ':uuid/duplicate',
                name: 'appPurchaseOrderDuplicate',
                meta: {
                    trans: 'global.add',
                    title: 'purchase.order.order',
                    permissions: ['create-purchase-order']
                },
                component: () => import('@views/app/purchase/order/edit' /* webpackChunkName: "app/purchase/order/edit" */ ),
            },
            {
                path: ':uuid',
                name: 'appPurchaseOrderView',
                meta: {
                    trans: 'global.view',
                    title: 'purchase.order.order',
                    permissions: ['list-purchase-order']
                },
                component: () => import('@views/app/purchase/order/view' /* webpackChunkName: "app/purchase/order/view" */ ),
            },
        ]
    },
]
