import { getOptionRoutes } from '../config/module-config'

export default [
    {
        path: 'challans',
        name: 'appSaleChallan',
        redirect: { name: 'appSaleChallanList' },
        meta: {
            title: 'sale.challan.challans',
            hideChildren: true,
            classes: 'secure-content',
            permissions: ['list-sale', 'create-sale', 'edit-sale']
        },
        component: {
            template: '<router-view></router-view>'
        },
        children: [
            {
                path: '',
                name: 'appSaleChallanList',
                meta: {
                    trans: 'global.list',
                    title: 'sale.challan.challans',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/challan/index' /* webpackChunkName: "app/sale/challan/index" */),
            },


            {
                path: 'config',
                name: 'appSaleChallanConfig',
                redirect: { name: 'appSaleChallanConfigGeneral' },
                meta: {
                    title: 'config.config',
                    permissions: ['access-sale-config'],
                    isConfigRoute: true,
                },
                component: () => import('@views/app/sale/challan/config/index' /* webpackChunkName: "app/sale/challan/config/index" */ ),
                children: [{
                        path: '',
                        name: 'appSaleChallanConfigGeneral',
                        meta: {
                            title: 'config.general',
                        },
                        component: () => import('@views/app/sale/challan/config/general' /* webpackChunkName: "app/sale/challan/config/general" */ ),
                    }, {
                        path: 'print',
                        name: 'appSaleChallanConfigPrint',
                        meta: {
                            title: 'config.print.print',
                        },
                        component: () => import('@views/app/sale/challan/config/print' /* webpackChunkName: "app/sale/challan/config/print" */ ),
                    },
                    getOptionRoutes({
                        path: 'transports',
                        entityTitle: 'setting.transport.transport',
                        entitiesTitle: 'setting.transport.transports',
                        entityDescription: 'setting.transport.module_description',
                        routeNamePrefix: 'appSaleChallanConfigTransport',
                        permissionRequired: 'access-sale-config',
                        optionType: 'transport',
                        hasSlug: false,
                    }),
                ]
            },


            {
                path: 'add',
                name: 'appSaleChallanAdd',
                meta: {
                    trans: 'global.add',
                    title: 'sale.challan.challan',
                    permissions: ['create-sale']
                },
                component: () => import('@views/app/sale/challan/add' /* webpackChunkName: "app/sale/challan/add" */),
            },
            {
                path: ':uuid/edit',
                name: 'appSaleChallanEdit',
                meta: {
                    trans: 'global.edit',
                    title: 'sale.challan.challan',
                    permissions: ['edit-sale']
                },
                component: () => import('@views/app/sale/challan/edit' /* webpackChunkName: "app/sale/challan/edit" */),
            },
            {
                path: ':uuid/duplicate',
                name: 'appSaleChallanDuplicate',
                meta: {
                    trans: 'global.add',
                    title: 'sale.challan.challan',
                    permissions: ['create-sale']
                },
                component: () => import('@views/app/sale/challan/edit' /* webpackChunkName: "app/sale/challan/edit" */),
            },
            {
                path: ':uuid/print',
                name: 'appSaleChallanPrint',
                meta: {
                    trans: 'global.print',
                    title: 'sale.challan.challan',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/challan/print' /* webpackChunkName: "app/sale/challan/print" */ ),
            },
            {
                path: ':uuid',
                name: 'appSaleChallanView',
                meta: {
                    trans: 'global.view',
                    title: 'sale.challan.challan',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/challan/view' /* webpackChunkName: "app/sale/challan/view" */ ),
            },
        ]
    },
]
