import { getOptionRoutes } from '../config/module-config'

export default [
    {
        path: 'invoices',
        name: 'appSaleInvoice',
        redirect: { name: 'appSaleInvoiceList' },
        meta: {
            title: 'sale.invoice.invoices',
            hideChildren: true,
            permissions: ['list-sale', 'create-sale', 'edit-sale']
        },
        component: {
            template: '<router-view></router-view>'
        },
        children: [
            {
                path: '',
                name: 'appSaleInvoiceList',
                meta: {
                    trans: 'global.list',
                    title: 'sale.invoice.invoices',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/invoice/index' /* webpackChunkName: "app/sale/invoice/index" */),
            },


            {
                path: 'config',
                name: 'appSaleInvoiceConfig',
                redirect: { name: 'appSaleInvoiceConfigGeneral' },
                meta: {
                    title: 'config.config',
                    permissions: ['access-sale-config'],
                    isConfigRoute: true,
                },
                component: () => import('@views/app/sale/invoice/config/index' /* webpackChunkName: "app/sale/invoice/config/index" */ ),
                children: [{
                        path: '',
                        name: 'appSaleInvoiceConfigGeneral',
                        meta: {
                            title: 'config.general',
                        },
                        component: () => import('@views/app/sale/invoice/config/general' /* webpackChunkName: "app/sale/invoice/config/general" */ ),
                    }, {
                        path: 'print',
                        name: 'appSaleInvoiceConfigPrint',
                        meta: {
                            title: 'config.print.print',
                        },
                        component: () => import('@views/app/sale/invoice/config/print' /* webpackChunkName: "app/sale/invoice/config/print" */ ),
                    },
                    getOptionRoutes({
                        path: 'transports',
                        entityTitle: 'setting.transport.transport',
                        entitiesTitle: 'setting.transport.transports',
                        entityDescription: 'setting.transport.module_description',
                        routeNamePrefix: 'appSaleInvoiceConfigTransport',
                        permissionRequired: 'access-sale-config',
                        optionType: 'transport',
                        hasSlug: false,
                    }),
                ]
            },


            {
                path: 'add',
                name: 'appSaleInvoiceAdd',
                meta: {
                    trans: 'global.add',
                    title: 'sale.invoice.invoice',
                    permissions: ['create-sale']
                },
                component: () => import('@views/app/sale/invoice/add' /* webpackChunkName: "app/sale/invoice/add" */),
            },
            {
                path: ':uuid/edit',
                name: 'appSaleInvoiceEdit',
                meta: {
                    trans: 'global.edit',
                    title: 'sale.invoice.invoice',
                    permissions: ['edit-sale']
                },
                component: () => import('@views/app/sale/invoice/edit' /* webpackChunkName: "app/sale/invoice/edit" */),
            },
            {
                path: ':uuid/duplicate',
                name: 'appSaleInvoiceDuplicate',
                meta: {
                    trans: 'global.add',
                    title: 'sale.invoice.invoice',
                    permissions: ['create-sale']
                },
                component: () => import('@views/app/sale/invoice/edit' /* webpackChunkName: "app/sale/invoice/edit" */),
            },
            {
                path: ':uuid/print',
                name: 'appSaleInvoicePrint',
                meta: {
                    trans: 'global.print',
                    title: 'sale.invoice.invoice',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/invoice/print' /* webpackChunkName: "app/sale/invoice/print" */ ),
            },
            {
                path: ':uuid',
                name: 'appSaleInvoiceView',
                meta: {
                    trans: 'global.view',
                    title: 'sale.invoice.invoice',
                    permissions: ['list-sale']
                },
                component: () => import('@views/app/sale/invoice/view' /* webpackChunkName: "app/sale/invoice/view" */ ),
            },
        ]
    },
]
