import { getOptionRoutes } from '../config/module-config'

export default [{
        path: 'quotations',
        name: 'appSaleQuotation',
        redirect: {
            name: 'appSaleQuotationList'
        },
        meta: {
            title: 'sale.quotation.quotations',
            hideChildren: true,
            permissions: ['list-quotation', 'create-quotation', 'edit-quotation'],
        },
        component: {
            template: '<router-view></router-view>'
        },
        children: [{
                path: '',
                name: 'appSaleQuotationList',
                meta: {
                    trans: 'global.list',
                    title: 'sale.quotation.quotations',
                    permissions: ['list-quotation']
                },
                component: () => import('@views/app/sale/quotation/index' /* webpackChunkName: "app/sale/quotation/index" */ ),
            },


            {
                path: 'config',
                name: 'appSaleQuotationConfig',
                redirect: { name: 'appSaleQuotationConfigGeneral' },
                meta: {
                    title: 'config.config',
                    permissions: ['access-quotation-config'],
                    isConfigRoute: true,
                },
                component: () => import('@views/app/sale/quotation/config/index' /* webpackChunkName: "app/sale/quotation/config/index" */ ),
                children: [{
                        path: '',
                        name: 'appSaleQuotationConfigGeneral',
                        meta: {
                            title: 'config.general',
                        },
                        component: () => import('@views/app/sale/quotation/config/general' /* webpackChunkName: "app/sale/quotation/config/general" */ ),
                    }, {
                        path: 'print',
                        name: 'appSaleQuotationConfigPrint',
                        meta: {
                            title: 'config.print.print',
                        },
                        component: () => import('@views/app/sale/quotation/config/print' /* webpackChunkName: "app/sale/quotation/config/print" */ ),
                    },
                    getOptionRoutes({
                        path: 'transports',
                        entityTitle: 'setting.transport.transport',
                        entitiesTitle: 'setting.transport.transports',
                        entityDescription: 'setting.transport.module_description',
                        routeNamePrefix: 'appSaleQuotationConfigTransport',
                        permissionRequired: 'access-quotation-config',
                        optionType: 'transport',
                        hasSlug: false,
                    }),
                ]
            },


            {
                path: 'add',
                name: 'appSaleQuotationAdd',
                meta: {
                    trans: 'global.add',
                    title: 'sale.quotation.quotation',
                    permissions: ['create-quotation']
                },
                component: () => import('@views/app/sale/quotation/add' /* webpackChunkName: "app/sale/quotation/add" */ ),
            },
            {
                path: ':uuid/edit',
                name: 'appSaleQuotationEdit',
                meta: {
                    trans: 'global.edit',
                    title: 'sale.quotation.quotation',
                    permissions: ['edit-quotation']
                },
                component: () => import('@views/app/sale/quotation/edit' /* webpackChunkName: "app/sale/quotation/edit" */ ),
            },
            {
                path: ':uuid/duplicate',
                name: 'appSaleQuotationDuplicate',
                meta: {
                    trans: 'global.add',
                    title: 'sale.quotation.quotation',
                    permissions: ['create-quotation']
                },
                component: () => import('@views/app/sale/quotation/edit' /* webpackChunkName: "app/sale/quotation/edit" */ ),
            },
            {
                path: ':uuid/print',
                name: 'appSaleQuotationPrint',
                meta: {
                    trans: 'global.print',
                    title: 'sale.quotation.quotation',
                    permissions: ['list-quotation']
                },
                component: () => import('@views/app/sale/quotation/print' /* webpackChunkName: "app/sale/quotation/print" */ ),
            },
            {
                path: ':uuid',
                name: 'appSaleQuotationView',
                meta: {
                    trans: 'global.view',
                    title: 'sale.quotation.quotation',
                    permissions: ['list-quotation']
                },
                component: () => import('@views/app/sale/quotation/view' /* webpackChunkName: "app/sale/quotation/view" */ ),
            },
        ]
    },
]
